MModuleRef class

Inheritance

Constructors

MModuleRef.ofParts(String developer, String module, String version)
const

Properties

developer → String
final
diffHashCode → int
no setterinherited
diffKey → String
no setterinherited
diffSource → dynamic
no setterinherited
equalityHashCode → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isKnown → bool
no setterinherited
module → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
operation(String name) → MOperationRef
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited